@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2010-2016 David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -45,10 +45,13 @@ UserAgentDialog::UserAgentDialog(QWidget* parent)
         os.prepend(QL1S("Wayland; "));
 #endif
 
+    QRegularExpression chromeRx(QSL("Chrome/([^\\s]+)"));
+    const QString chromeVersion = chromeRx.match(m_manager->defaultUserAgent()).captured(1);
+
     m_knownUserAgents << QString("Opera/9.80 (%1) Presto/2.12.388 Version/12.16").arg(os)
-                      << QString("Mozilla/5.0 (%1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2704.84 Safari/537.36").arg(os)
-                      << QString("Mozilla/5.0 (%1) AppleWebKit/601.2.7 (KHTML, like Gecko) Version/9.0.1 Safari/601.2.7").arg(os)
-                      << QString("Mozilla/5.0 (%1; rv:47.0) Gecko/20100101 Firefox/47.0").arg(os);
+                      << QString("Mozilla/5.0 (%1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/%2 Safari/537.36").arg(os, chromeVersion)
+                      << QString("Mozilla/5.0 (%1) AppleWebKit/602.3.12 (KHTML, like Gecko) Version/10.0.2 Safari/602.3.12").arg(os)
+                      << QString("Mozilla/5.0 (%1; rv:57.0) Gecko/20100101 Firefox/57.0").arg(os);
 
     ui->globalComboBox->addItems(m_knownUserAgents);
 
@@ -85,11 +88,6 @@ UserAgentDialog::UserAgentDialog(QWidget* parent)
 
     enableGlobalComboBox(ui->changeGlobal->isChecked());
     enablePerSiteFrame(ui->changePerSite->isChecked());
-
-#if !QTWEBENGINE_DISABLED
-    ui->perSiteFrame->setVisible(false);
-    ui->changePerSite->setVisible(false);
-#endif
 }
 
 void UserAgentDialog::addSite()
