@@ -71,9 +71,10 @@ WebPage::WebPage(QObject* parent)
     , m_loadProgress(-1)
     , m_blockAlerts(false)
     , m_secureStatus(false)
-    , m_adjustingScheduled(false)
 {
-    setupWebChannel();
+    QWebChannel *channel = new QWebChannel(this);
+    channel->registerObject(QSL("qz_object"), new ExternalJsObject(this));
+    setWebChannel(channel);
 
     connect(this, &QWebEnginePage::loadProgress, this, &WebPage::progress);
     connect(this, &QWebEnginePage::loadFinished, this, &WebPage::finished);
@@ -90,6 +91,16 @@ WebPage::WebPage(QObject* parent)
     connect(this, &QWebEnginePage::proxyAuthenticationRequired, this, [this](const QUrl &, QAuthenticator *auth, const QString &proxyHost) {
         mApp->networkManager()->proxyAuthentication(proxyHost, auth, view());
     });
+
+    // Workaround QWebEnginePage not scrolling to anchors when opened in background tab
+    m_contentsResizedConnection = connect(this, &QWebEnginePage::contentsSizeChanged, this, [this]() {
+        const QString fragment = url().fragment();
+        if (!fragment.isEmpty()) {
+            const QString src = QSL("var els = document.querySelectorAll(\"[name='%1']\"); if (els.length) els[0].scrollIntoView();");
+            runJavaScript(src.arg(fragment));
+        }
+        disconnect(m_contentsResizedConnection);
+    });
 }
 
 WebPage::~WebPage()
@@ -107,6 +118,25 @@ WebView *WebPage::view() const
     return static_cast<WebView*>(QWebEnginePage::view());
 }
 
+bool WebPage::execPrintPage(QPrinter *printer, int timeout)
+{
+    QPointer<QEventLoop> loop = new QEventLoop;
+    bool result = false;
+    QTimer::singleShot(timeout, loop.data(), &QEventLoop::quit);
+
+    print(printer, [loop, &result](bool res) {
+        if (loop && loop->isRunning()) {
+            result = res;
+            loop->quit();
+        }
+    });
+
+    loop->exec();
+    delete loop;
+
+    return result;
+}
+
 QVariant WebPage::execJavaScript(const QString &scriptSource, quint32 worldId, int timeout)
 {
     QPointer<QEventLoop> loop = new QEventLoop;
@@ -120,32 +150,12 @@ QVariant WebPage::execJavaScript(const QString &scriptSource, quint32 worldId, i
         }
     });
 
-    loop->exec();
+    loop->exec(QEventLoop::ExcludeUserInputEvents);
     delete loop;
 
     return result;
 }
 
-void WebPage::runJavaScript(const QString &scriptSource)
-{
-    return QWebEnginePage::runJavaScript(scriptSource);
-}
-
-void WebPage::runJavaScript(const QString &scriptSource, const QWebEngineCallback<const QVariant &> &resultCallback)
-{
-    return QWebEnginePage::runJavaScript(scriptSource, resultCallback);
-}
-
-void WebPage::runJavaScript(const QString &scriptSource, quint32 worldId)
-{
-    QWebEnginePage::runJavaScript(scriptSource, worldId);
-}
-
-void WebPage::runJavaScript(const QString &scriptSource, quint32 worldId, const QWebEngineCallback<const QVariant &> &resultCallback)
-{
-    QWebEnginePage::runJavaScript(scriptSource, worldId, resultCallback);
-}
-
 QPointF WebPage::mapToViewport(const QPointF &pos) const
 {
     return QPointF(pos.x() / zoomFactor(), pos.y() / zoomFactor());
@@ -167,20 +177,6 @@ void WebPage::setScrollPosition(const QPointF &pos)
     runJavaScript(QSL("window.scrollTo(%1, %2)").arg(v.x()).arg(v.y()), WebPage::SafeJsWorld);
 }
 
-void WebPage::scheduleAdjustPage()
-{
-    if (view()->isLoading()) {
-        m_adjustingScheduled = true;
-    }
-    else {
-        const QSize originalSize = view()->size();
-        QSize newSize(originalSize.width() - 1, originalSize.height() - 1);
-
-        view()->resize(newSize);
-        view()->resize(originalSize);
-    }
-}
-
 bool WebPage::isRunningLoop()
 {
     return m_runningLoop;
@@ -216,12 +212,6 @@ void WebPage::finished()
 {
     progress(100);
 
-    if (m_adjustingScheduled) {
-        m_adjustingScheduled = false;
-        setZoomFactor(zoomFactor() + 1);
-        setZoomFactor(zoomFactor() - 1);
-    }
-
     // File scheme watcher
     if (url().scheme() == QLatin1String("file")) {
         QFileInfo info(url().toLocalFile());
@@ -275,7 +265,7 @@ void WebPage::handleUnknownProtocol(const QUrl &url)
         return;
     }
 
-    CheckBoxDialog dialog(QDialogButtonBox::Yes | QDialogButtonBox::No, view());
+    CheckBoxDialog dialog(QMessageBox::Yes | QMessageBox::No, view());
 
     const QString wrappedUrl = QzTools::alignTextToWidth(url.toString(), "<br/>", dialog.fontMetrics(), 450);
     const QString text = tr("QupZilla cannot handle <b>%1:</b> links. The requested link "
@@ -285,10 +275,10 @@ void WebPage::handleUnknownProtocol(const QUrl &url)
     dialog.setText(text);
     dialog.setCheckBoxText(tr("Remember my choice for this protocol"));
     dialog.setWindowTitle(tr("External Protocol Request"));
-    dialog.setIcon(IconProvider::standardIcon(QStyle::SP_MessageBoxQuestion));
+    dialog.setIcon(QMessageBox::Question);
 
     switch (dialog.exec()) {
-    case QDialog::Accepted:
+    case QMessageBox::Yes:
         if (dialog.isChecked()) {
             qzSettings->autoOpenProtocols.append(protocol);
             qzSettings->saveSettings();
@@ -298,7 +288,7 @@ void WebPage::handleUnknownProtocol(const QUrl &url)
         QDesktopServices::openUrl(url);
         break;
 
-    case QDialog::Rejected:
+    case QMessageBox::No:
         if (dialog.isChecked()) {
             qzSettings->blockedProtocols.append(protocol);
             qzSettings->saveSettings();
@@ -327,21 +317,6 @@ void WebPage::desktopServicesOpen(const QUrl &url)
     }
 }
 
-void WebPage::setupWebChannel()
-{
-    QWebChannel *old = webChannel();
-    const QString objectName = QSL("qz_object");
-
-    QWebChannel *channel = new QWebChannel(this);
-    channel->registerObject(QSL("qz_object"), new ExternalJsObject(this));
-    setWebChannel(channel);
-
-    if (old) {
-        delete old->registeredObjects().value(objectName);
-        delete old;
-    }
-}
-
 void WebPage::windowCloseRequested()
 {
     if (!view())
@@ -564,11 +539,11 @@ void WebPage::javaScriptAlert(const QUrl &securityOrigin, const QString &msg)
         title.append(QString(" - %1").arg(url().host()));
     }
 
-    CheckBoxDialog dialog(QDialogButtonBox::Ok, view());
+    CheckBoxDialog dialog(QMessageBox::Ok, view());
     dialog.setWindowTitle(title);
     dialog.setText(msg);
     dialog.setCheckBoxText(tr("Prevent this page from creating additional dialogs"));
-    dialog.setIcon(IconProvider::standardIcon(QStyle::SP_MessageBoxInformation));
+    dialog.setIcon(QMessageBox::Information);
     dialog.exec();
 
     m_blockAlerts = dialog.isChecked();
@@ -616,6 +591,15 @@ QWebEnginePage* WebPage::createWindow(QWebEnginePage::WebWindowType type)
         int index = window->tabWidget()->addView(QUrl(), pos);
         TabbedWebView* view = window->weView(index);
         view->setPage(new WebPage);
+        // Workaround focus issue when creating tab
+        if (pos.testFlag(Qz::NT_SelectedTab)) {
+            QPointer<TabbedWebView> pview = view;
+            QTimer::singleShot(0, this, [pview]() {
+                if (pview && pview->webTab()->isCurrentTab()) {
+                    pview->setFocus();
+                }
+            });
+        }
         return view->page();
     };
 
