@@ -47,14 +47,9 @@ public:
 
     WebView *view() const;
 
+    bool execPrintPage(QPrinter *printer, int timeout = 1000);
     QVariant execJavaScript(const QString &scriptSource, quint32 worldId = QWebEngineScript::MainWorld, int timeout = 500);
 
-    // TODO: Remove when depending on Qt 5.7
-    void runJavaScript(const QString &scriptSource);
-    void runJavaScript(const QString &scriptSource, const QWebEngineCallback<const QVariant &> &resultCallback);
-    void runJavaScript(const QString &scriptSource, quint32 worldId);
-    void runJavaScript(const QString &scriptSource, quint32 worldId, const QWebEngineCallback<const QVariant &> &resultCallback);
-
     QPointF mapToViewport(const QPointF &pos) const;
     WebHitTestResult hitTestContent(const QPoint &pos) const;
 
@@ -70,13 +65,10 @@ public:
     bool hasMultipleUsernames() const;
     QVector<PasswordEntry> autoFillData() const;
 
-    void scheduleAdjustPage();
     bool isRunningLoop();
 
     bool isLoading() const;
 
-    void setupWebChannel();
-
 signals:
     void privacyChanged(bool status);
 
@@ -114,7 +106,6 @@ private:
     int m_loadProgress;
     bool m_blockAlerts;
     bool m_secureStatus;
-    bool m_adjustingScheduled;
 
     QMetaObject::Connection m_contentsResizedConnection;
 };
