@@ -82,8 +82,14 @@ QString GM_Manager::requireScripts(const QStringList &urlList) const
 
     foreach (const QString &url, urlList) {
         if (settings.contains(url)) {
-            const QString fileName = settings.value(url).toString();
-            script.append(QzTools::readAllFileContents(fileName).trimmed() + '\n');
+            QString fileName = settings.value(url).toString();
+            if (!QFileInfo(fileName).isAbsolute()) {
+                fileName = m_settingsPath + QL1S("/greasemonkey/requires/") + fileName;
+            }
+            const QString data = QzTools::readAllFileContents(fileName).trimmed();
+            if (!data.isEmpty()) {
+                script.append(data + QL1C('\n'));
+            }
         }
     }
 
