@@ -1,6 +1,6 @@
 /* ============================================================
 * GreaseMonkey plugin for QupZilla
-* Copyright (C) 2012-2016  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2012-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "mainapplication.h"
 
 #include <QFile>
+#include <QTextStream>
 #include <QStringList>
 #include <QWebEngineScript>
 #include <QCryptographicHash>
@@ -115,9 +116,9 @@ QStringList GM_Script::exclude() const
     return m_exclude;
 }
 
-QString GM_Script::script() const
+QStringList GM_Script::require() const
 {
-    return m_script;
+    return m_require;
 }
 
 QString GM_Script::fileName() const
@@ -127,27 +128,11 @@ QString GM_Script::fileName() const
 
 QWebEngineScript GM_Script::webScript() const
 {
-    QWebEngineScript::InjectionPoint injectionPoint;
-    switch (startAt()) {
-    case DocumentStart:
-        injectionPoint = QWebEngineScript::DocumentCreation;
-        break;
-    case DocumentEnd:
-        injectionPoint = QWebEngineScript::DocumentReady;
-        break;
-    case DocumentIdle:
-        injectionPoint = QWebEngineScript::Deferred;
-        break;
-    default:
-        Q_UNREACHABLE();
-    }
-
     QWebEngineScript script;
+    script.setSourceCode(QSL("%1\n%2").arg(m_manager->bootstrapScript(), m_script));
     script.setName(fullName());
     script.setWorldId(QWebEngineScript::MainWorld);
-    script.setInjectionPoint(injectionPoint);
     script.setRunsOnSubFrames(!m_noframes);
-    script.setSourceCode(QSL("%1\n%2").arg(m_manager->bootstrapScript(), m_script));
     return script;
 }
 
@@ -174,42 +159,16 @@ void GM_Script::updateScript()
         m_updating = false;
         emit updatingChanged(m_updating);
     });
+    downloadRequires();
 }
 
 void GM_Script::watchedFileChanged(const QString &file)
 {
     if (m_fileName == file) {
-        parseScript();
-
-        m_manager->removeScript(this, false);
-        m_manager->addScript(this);
-
-        emit scriptChanged();
+        reloadScript();
     }
 }
 
-static QString toJavaScriptList(const QStringList &patterns)
-{
-    QString out;
-    foreach (const QString &pattern, patterns) {
-        QString p;
-        if (pattern.startsWith(QL1C('/')) && pattern.endsWith(QL1C('/')) && pattern.size() > 1) {
-            p = pattern.mid(1, pattern.size() - 2);
-        } else {
-            p = pattern;
-            p.replace(QL1S("."), QL1S("\\."));
-            p.replace(QL1S("*"), QL1S(".*"));
-        }
-        p = QSL("'%1'").arg(p);
-        if (out.isEmpty()) {
-            out.append(p);
-        } else {
-            out.append(QL1C(',') + p);
-        }
-    }
-    return QSL("[%1]").arg(out);
-}
-
 void GM_Script::parseScript()
 {
     m_name.clear();
@@ -218,6 +177,7 @@ void GM_Script::parseScript()
     m_version.clear();
     m_include.clear();
     m_exclude.clear();
+    m_require.clear();
     m_downloadUrl.clear();
     m_updateUrl.clear();
     m_startAt = DocumentEnd;
@@ -236,22 +196,23 @@ void GM_Script::parseScript()
         m_fileWatcher->addPath(m_fileName);
     }
 
-    const QString fileData = QString::fromUtf8(file.readAll());
+    const QByteArray fileData = file.readAll();
 
-    QzRegExp rx(QSL("(?:^|[\\r\\n])// ==UserScript==(.*)(?:\\r\\n|[\\r\\n])// ==/UserScript==(?:[\\r\\n]|$)"));
-    rx.indexIn(fileData);
-    QString metadataBlock = rx.cap(1).trimmed();
+    bool inMetadata = false;
 
-    if (metadataBlock.isEmpty()) {
-        qWarning() << "GreaseMonkey: File does not contain metadata block" << m_fileName;
-        return;
-    }
+    QTextStream stream(fileData);
+    QString line;
+    while (stream.readLineInto(&line)) {
+        if (line.startsWith(QL1S("// ==UserScript=="))) {
+            inMetadata = true;
+        }
+        if (line.startsWith(QL1S("// ==/UserScript=="))) {
+            break;
+        }
+        if (!inMetadata) {
+            continue;
+        }
 
-    QStringList requireList;
-    QzRegExp rxNL(QSL("(?:\\r\\n|[\\r\\n])"));
-
-    const QStringList lines = metadataBlock.split(rxNL, QString::SkipEmptyParts);
-    foreach (QString line, lines) {
         if (!line.startsWith(QLatin1String("// @"))) {
             continue;
         }
@@ -295,7 +256,7 @@ void GM_Script::parseScript()
             m_exclude.append(value);
         }
         else if (key == QLatin1String("@require")) {
-            requireList.append(value);
+            m_require.append(value);
         }
         else if (key == QLatin1String("@run-at")) {
             if (value == QLatin1String("document-end")) {
@@ -310,31 +271,39 @@ void GM_Script::parseScript()
         }
     }
 
+    if (!inMetadata) {
+        qWarning() << "GreaseMonkey: File does not contain metadata block" << m_fileName;
+        return;
+    }
+
     if (m_include.isEmpty()) {
         m_include.append(QSL("*"));
     }
 
     const QString nspace = QCryptographicHash::hash(fullName().toUtf8(), QCryptographicHash::Md4).toHex();
     const QString gmValues = m_manager->valuesScript().arg(nspace);
-    const QString runCheck = QString(QL1S("for (var value of %1) {"
-                                          "    var re = new RegExp(value);"
-                                          "    if (re.test(window.location.href)) {"
-                                          "        return;"
-                                          "    }"
-                                          "}"
-                                          "__qz_includes = false;"
-                                          "for (var value of %2) {"
-                                          "    var re = new RegExp(value);"
-                                          "    if (re.test(window.location.href)) {"
-                                          "        __qz_includes = true;"
-                                          "        break;"
-                                          "    }"
-                                          "}"
-                                          "if (!__qz_includes) {"
-                                          "    return;"
-                                          "}"
-                                          "delete __qz_includes;")).arg(toJavaScriptList(m_exclude), toJavaScriptList(m_include));
-
-    m_script = QSL("(function(){%1\n%2\n%3\n%4\n})();").arg(runCheck, gmValues, m_manager->requireScripts(requireList), fileData);
+    m_script = QSL("(function(){%1\n%2\n%3\n})();").arg(gmValues, m_manager->requireScripts(m_require), fileData);
     m_valid = true;
+
+    downloadRequires();
+}
+
+void GM_Script::reloadScript()
+{
+    parseScript();
+
+    m_manager->removeScript(this, false);
+    m_manager->addScript(this);
+
+    emit scriptChanged();
+}
+
+void GM_Script::downloadRequires()
+{
+    for (const QString &url : qAsConst(m_require)) {
+        if (m_manager->requireScripts({url}).isEmpty()) {
+            GM_Downloader *downloader = new GM_Downloader(QUrl(url), m_manager, GM_Downloader::DownloadRequireScript);
+            connect(downloader, &GM_Downloader::finished, this, &GM_Script::reloadScript);
+        }
+    }
 }
