@@ -7,47 +7,47 @@
         <translation>GreaseMonkey 脚本安装</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="51"/>
+        <location filename="../gm_addscriptdialog.ui" line="45"/>
         <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
         <translation>&lt;H3&gt;GreaseMonkey 脚本安装&lt;/H3&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="73"/>
+        <location filename="../gm_addscriptdialog.ui" line="67"/>
         <source>You are about to install this userscript into GreaseMonkey:</source>
         <translation>将向 GreaseMonkey 安装如下用户脚本：</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="86"/>
+        <location filename="../gm_addscriptdialog.ui" line="80"/>
         <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
         <translation>&lt;B&gt;您只应安装来自可信来源的用户脚本！&lt;/B&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="96"/>
+        <location filename="../gm_addscriptdialog.ui" line="90"/>
         <source>Are you sure you want to install it?</source>
         <translation>确认要安装该脚本吗？</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="114"/>
+        <location filename="../gm_addscriptdialog.ui" line="108"/>
         <source>Show source code of script</source>
         <translation>显示脚本源代码</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="49"/>
+        <location filename="../gm_addscriptdialog.cpp" line="50"/>
         <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
         <translation>&lt;P&gt;生效于下列网址：&lt;BR /&gt;&lt;I&gt;%1&lt;/I&gt;&lt;/P&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="53"/>
+        <location filename="../gm_addscriptdialog.cpp" line="54"/>
         <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
         <translation>&lt;P&gt;不生效于下列网址：&lt;BR /&gt;&lt;I&gt;%1&lt;/I&gt;&lt;/P&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="83"/>
+        <location filename="../gm_addscriptdialog.cpp" line="84"/>
         <source>Cannot install script</source>
         <translation>无法安装脚本</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="86"/>
+        <location filename="../gm_addscriptdialog.cpp" line="87"/>
         <source>&apos;%1&apos; installed successfully</source>
         <translation>脚本“%1”安装成功</translation>
     </message>
@@ -63,35 +63,35 @@
 <context>
     <name>GM_Manager</name>
     <message>
-        <location filename="../gm_manager.cpp" line="206"/>
+        <location filename="../gm_manager.cpp" line="203"/>
         <source>GreaseMonkey</source>
         <translation>GreaseMonkey</translation>
     </message>
     <message>
-        <location filename="../gm_manager.cpp" line="270"/>
+        <location filename="../gm_manager.cpp" line="267"/>
         <source>&apos;%1&apos; is already installed</source>
-        <translation type="unfinished"/>
+        <translation>“%1”已经安装</translation>
     </message>
 </context>
 <context>
     <name>GM_Notification</name>
     <message>
-        <location filename="../gm_notification.ui" line="45"/>
+        <location filename="../gm_notification.ui" line="39"/>
         <source>This script can be installed with the GreaseMonkey plugin.</source>
         <translation>该脚本可通过 GreaseMonkey 安装。</translation>
     </message>
     <message>
-        <location filename="../gm_notification.ui" line="65"/>
+        <location filename="../gm_notification.ui" line="59"/>
         <source>Install</source>
         <translation>安装</translation>
     </message>
     <message>
-        <location filename="../gm_notification.cpp" line="50"/>
+        <location filename="../gm_notification.cpp" line="51"/>
         <source>Cannot install script</source>
         <translation>未能安装脚本</translation>
     </message>
     <message>
-        <location filename="../gm_notification.cpp" line="58"/>
+        <location filename="../gm_notification.cpp" line="59"/>
         <source>&apos;%1&apos; installed successfully</source>
         <translation>脚本“%1”安装成功</translation>
     </message>
@@ -104,47 +104,47 @@
         <translation>GreaseMonkey 脚本</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="51"/>
+        <location filename="../settings/gm_settings.ui" line="48"/>
         <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
         <translation>&lt;H3&gt;GreaseMonkey 脚本&lt;/H3&gt;</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="73"/>
+        <location filename="../settings/gm_settings.ui" line="70"/>
         <source>Double clicking script will show additional information</source>
         <translation>双击脚本以显示详情</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="153"/>
+        <location filename="../settings/gm_settings.ui" line="150"/>
         <source>More scripts can be downloaded from</source>
         <translation>要下载、安装更多脚本，请至</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="196"/>
+        <location filename="../settings/gm_settings.ui" line="193"/>
         <source>Open scripts directory</source>
         <translation>打开脚本文件夹</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="203"/>
+        <location filename="../settings/gm_settings.ui" line="200"/>
         <source>New user script</source>
         <translation>新建用户脚本</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="90"/>
+        <location filename="../settings/gm_settings.cpp" line="91"/>
         <source>Remove script</source>
         <translation>移除脚本</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="91"/>
+        <location filename="../settings/gm_settings.cpp" line="92"/>
         <source>Are you sure you want to remove &apos;%1&apos;?</source>
         <translation>您确定要移除脚本“%1”吗？</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="121"/>
+        <location filename="../settings/gm_settings.cpp" line="122"/>
         <source>Add script</source>
         <translation>添加脚本</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="121"/>
+        <location filename="../settings/gm_settings.cpp" line="122"/>
         <source>Choose name for script:</source>
         <translation>请输入脚本名称：</translation>
     </message>
